Changelog
=========

1.0 (2017-05-13)
----------------

- Add support for Python 3.4 up to 3.6, PyPy2 and PyPy3.

- Drop support for Python 2.5 and 2.6.

- Change license from ZPL to MIT.


0.3 (2012-11-13)
----------------

- Moved sources to bitbucket.org.

- Added Travis-CI.

- Dropped official support for Python 2.3 and Python 2.4. (Although these
  rather old Python versions still might be used with this release.)


0.2.1 (2011-07-28)
------------------

- Updated categories: Python 2.7 is supported, too.


0.2 (2009-09-26)
----------------

- Added ability pass a string used as ellipsis string.


0.1 (2009-01-31)
----------------

- Initial public release.

